@@ -1,9 +1,9 @@
-from matplotlib.pyplot import show
-
 from roboplot.trajectory.two_d import *
 from roboplot.trajectory.three_d import *
 from roboplot.trajectory.trajectory import *
 from roboplot.graph import *
+from roboplot.measurements import *
+from roboplot.sequence import *
 try:
     from roboplot.robot import *
 except ImportError:
